Stan Math Library: stan/math/prim/mat/fun/read_cov_L.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
read_cov_L.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::read_cov_L (const Eigen::Array< T, Eigen::Dynamic, 1 > &CPCs, const Eigen::Array< T, Eigen::Dynamic, 1 > &sds, T &log_prob)
| This is the function that should be called prior to evaluating the density of any elliptical distribution. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.